@@ -4,7 +4,7 @@ use std::fmt;
 use std::ops::Range;
 use std::str::FromStr;
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, Eq, PartialEq)]
 pub enum BoundsType {
     Bytes,
     Characters,
@@ -12,7 +12,7 @@ pub enum BoundsType {
     Lines,
 }
 
-#[derive(Debug, PartialEq)]
+#[derive(Debug, Eq, PartialEq)]
 pub enum BoundOrFiller {
     Bound(UserBounds),
     Filler(String),
@@ -32,7 +32,7 @@ pub fn parse_bounds_list(s: &str) -> Result<Vec<BoundOrFiller>> {
         return Ok(Vec::new());
     }
 
-    if s.contains(&['{', '}']) {
+    if s.contains(['{', '}']) {
         let mut bof: Vec<BoundOrFiller> = Vec::new();
         let mut inside_bound = false;
         let mut part_start = 0;
@@ -195,7 +195,7 @@ impl FromStr for Side {
 impl fmt::Display for Side {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         match self {
-            Side::Some(v) => write!(f, "{}", v),
+            Side::Some(v) => write!(f, "{v}"),
             Side::Continue => write!(f, ""),
         }
     }
@@ -211,8 +211,8 @@ impl fmt::Display for UserBounds {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         match (self.l, self.r) {
             (Side::Continue, Side::Continue) => write!(f, "1:-1"),
-            (l, r) if l == r => write!(f, "{}", l),
-            (l, r) => write!(f, "{}:{}", l, r),
+            (l, r) if l == r => write!(f, "{l}"),
+            (l, r) => write!(f, "{l}:{r}"),
         }
     }
 }
@@ -342,11 +342,11 @@ pub fn bounds_to_std_range(parts_length: usize, bounds: &UserBounds) -> Result<R
     let start: usize = match bounds.l {
         Side::Continue => 0,
         Side::Some(v) => {
-            if v.abs() as usize > parts_length {
+            if v.unsigned_abs() as usize > parts_length {
                 bail!("Out of bounds: {}", v);
             }
             if v < 0 {
-                parts_length - v.abs() as usize
+                parts_length - v.unsigned_abs() as usize
             } else {
                 v as usize - 1
             }
@@ -356,11 +356,11 @@ pub fn bounds_to_std_range(parts_length: usize, bounds: &UserBounds) -> Result<R
     let end: usize = match bounds.r {
         Side::Continue => parts_length,
         Side::Some(v) => {
-            if v.abs() as usize > parts_length {
+            if v.unsigned_abs() as usize > parts_length {
                 bail!("Out of bounds: {}", v);
             }
             if v < 0 {
-                parts_length - v.abs() as usize + 1
+                parts_length - v.unsigned_abs() as usize + 1
             } else {
                 v as usize
             }
